/*
 * Copyright [2022] [https://www.baiduc.com]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.baiduc.com
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.baiduc.com
 */
package vip.xiaonuo.hr.modular.basedepartment.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.common.pojo.CommonValidList;
import vip.xiaonuo.hr.modular.basedepartment.entity.HrBaseDepartment;
import vip.xiaonuo.hr.modular.basedepartment.param.HrBaseDepartmentAddParam;
import vip.xiaonuo.hr.modular.basedepartment.param.HrBaseDepartmentEditParam;
import vip.xiaonuo.hr.modular.basedepartment.param.HrBaseDepartmentIdParam;
import vip.xiaonuo.hr.modular.basedepartment.param.HrBaseDepartmentPageParam;
import vip.xiaonuo.hr.modular.basedepartment.service.HrBaseDepartmentService;


import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 人员部门控制器
 *
 * @author 余
 * @date  2024/12/16 11:09
 */
@Api(tags = "人员部门控制器")
@ApiSupport(author = "SNOWY_TEAM", order = 1)
@RestController
@Validated
public class HrBaseDepartmentController {

    @Resource
    private HrBaseDepartmentService hrBaseDepartmentService;

    /**
     * 获取人员部门分页
     *
     * @author 余
     * @date  2024/12/16 11:09
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取人员部门分页")
    @GetMapping("/biz/basedepartment/page")
    public CommonResult<Page<HrBaseDepartment>> page(HrBaseDepartmentPageParam hrBaseDepartmentPageParam) {
        return CommonResult.data(hrBaseDepartmentService.page(hrBaseDepartmentPageParam));
    }

    /**
     * 添加人员部门
     *
     * @author 余
     * @date  2024/12/16 11:09
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加人员部门")
    @CommonLog("添加人员部门")
    @PostMapping("/biz/basedepartment/add")
    public CommonResult<String> add(@RequestBody @Valid HrBaseDepartmentAddParam hrBaseDepartmentAddParam) {
        hrBaseDepartmentService.add(hrBaseDepartmentAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑人员部门
     *
     * @author 余
     * @date  2024/12/16 11:09
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑人员部门")
    @CommonLog("编辑人员部门")
    @PostMapping("/biz/basedepartment/edit")
    public CommonResult<String> edit(@RequestBody @Valid HrBaseDepartmentEditParam hrBaseDepartmentEditParam) {
        hrBaseDepartmentService.edit(hrBaseDepartmentEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除人员部门
     *
     * @author 余
     * @date  2024/12/16 11:09
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除人员部门")
    @CommonLog("删除人员部门")
    @PostMapping("/biz/basedepartment/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                               CommonValidList<HrBaseDepartmentIdParam> hrBaseDepartmentIdParamList) {
        hrBaseDepartmentService.delete(hrBaseDepartmentIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取人员部门详情
     *
     * @author 余
     * @date  2024/12/16 11:09
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取人员部门详情")
    @GetMapping("/biz/basedepartment/detail")
    public CommonResult<HrBaseDepartment> detail(@Valid HrBaseDepartmentIdParam hrBaseDepartmentIdParam) {
        return CommonResult.data(hrBaseDepartmentService.detail(hrBaseDepartmentIdParam));
    }
}
